# AUTOGENERATED! DO NOT EDIT! File to edit: ../00_card.ipynb.

# %% auto 0
__all__ = ['suits', 'ranks', 'Card']

# %% ../00_card.ipynb 2
from fastcore.utils import *

# %% ../00_card.ipynb 4
suits = ['♣️','♦️','❤️','♠️']
ranks = [None, "A"] + [str(x) for x in range(2,11)] + ["J", "Q", "K"]

# %% ../00_card.ipynb 12
class Card: 
    "A playing card"
    def __init__(self, 
                 suit:int,  # An index into `suits`
                 rank:int): # An index into `ranks` 
        self.suit, self.rank = suit, rank
    def __str__(self): return f'{ranks[self.rank]}{suits[self.suit]}'
    __repr__ = __str__
    

# %% ../00_card.ipynb 19
@patch
def __eq__(self:Card,other:Card): return (self.suit,self.rank)==(other.suit,other.rank)
@patch
def __lt__(self:Card,other:Card): return (self.suit,self.rank)<(other.suit,other.rank)
@patch
def __gt__(self:Card,other:Card): return (self.suit,self.rank)>(other.suit,other.rank)



# AUTOGENERATED! DO NOT EDIT! File to edit: ../01_deck.ipynb.

# %% auto 0
__all__ = ['Deck', 'draw_n']

# %% ../01_deck.ipynb 1
from fastcore.utils import *

# %% ../01_deck.ipynb 3
from .card import *

# %% ../01_deck.ipynb 5
class Deck:
    "A deck of 52 cards"
    def __init__(self): self.cards =[Card(suit=s,rank=r) for s in range(4) for r in range(1,14)] 
    def __len__(self): return len(self.cards)
    def __str__(self): return "; ".join(map(str,self.cards))
    def __contains__(self,card:Card): return card in self.cards
    __repr__ = __str__
    
    def shuffle(self):
        "Shuffles the cards in the deck"
        random.shuffle(self.cards)

# %% ../01_deck.ipynb 13
@patch
def pop(self:Deck,
        idx: int = -1): # The index of the card to remove, defaulting to the last one.
    "Remove one card from the deck"
    return self.cards.pop(idx)

# %% ../01_deck.ipynb 17
@patch
def remove(self:Deck,
        card: Card):
    "Removes `card` from the deck. Raises an exception if it is not there"
    return self.cards.remove(card)

# %% ../01_deck.ipynb 20
def draw_n(n:int, # number of cards to draw
           replace:bool=True): # whether or not draw with replacement
    "Draw `n` cards, with replacement if `replace`"
    d = Deck()
    d.shuffle()
    if replace: return [d.cards[random.choice(range(len(d.cards)))] for _ in range(n)]
    else: return d.cards[:n]



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/taash',
                'doc_host': 'https://nasheqlbrm.github.io',
                'git_url': 'https://github.com/nasheqlbrm/taash',
                'lib_path': 'taash'},
  'syms': { 'taash.card': { 'taash.card.Card': ('card.html#card', 'taash/card.py'),
                            'taash.card.Card.__eq__': ('card.html#card.__eq__', 'taash/card.py'),
                            'taash.card.Card.__gt__': ('card.html#card.__gt__', 'taash/card.py'),
                            'taash.card.Card.__init__': ('card.html#card.__init__', 'taash/card.py'),
                            'taash.card.Card.__lt__': ('card.html#card.__lt__', 'taash/card.py'),
                            'taash.card.Card.__str__': ('card.html#card.__str__', 'taash/card.py')},
            'taash.deck': { 'taash.deck.Deck': ('deck.html#deck', 'taash/deck.py'),
                            'taash.deck.Deck.__contains__': ('deck.html#deck.__contains__', 'taash/deck.py'),
                            'taash.deck.Deck.__init__': ('deck.html#deck.__init__', 'taash/deck.py'),
                            'taash.deck.Deck.__len__': ('deck.html#deck.__len__', 'taash/deck.py'),
                            'taash.deck.Deck.__str__': ('deck.html#deck.__str__', 'taash/deck.py'),
                            'taash.deck.Deck.pop': ('deck.html#deck.pop', 'taash/deck.py'),
                            'taash.deck.Deck.remove': ('deck.html#deck.remove', 'taash/deck.py'),
                            'taash.deck.Deck.shuffle': ('deck.html#deck.shuffle', 'taash/deck.py'),
                            'taash.deck.draw_n': ('deck.html#draw_n', 'taash/deck.py')}}}